@@ -30,7 +30,7 @@ require_once('../include/sendmail.php');
 # Block here potential robots.
 dnsbl_check();
 
-extract(sane_import('get', array('form_user')));
+extract(sane_import('get', ['name' => 'form_user']));
 $res_user = db_execute("SELECT * FROM user WHERE user_name=?", array($form_user));
 $row_user = db_fetch_array($res_user);
 
