@@ -2,7 +2,7 @@
 # Form functions.
 #
 # Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017 Ineiev
+# Copyright (C) 2017, 2022 Ineiev
 #
 # This file is part of Savane.
 #
@@ -19,8 +19,9 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once(dirname(__FILE__).'/dnsbl.php');
-require_once(dirname(__FILE__).'/spam.php');
+$dir_name = dirname (__FILE__);
+require_once ("$dir_name/dnsbl.php");
+require_once ("$dir_name/spam.php");
 
 # To use this form that disallow duplicates:
 #    - form_header must be used on the form
@@ -81,6 +82,14 @@ function form_checkbox ($name, $is_checked = 0, $attr = [])
   return form_input ('checkbox', $name, $val, $extra);
 }
 
+function form_hidden ($name_val)
+{
+  $ret = '';
+  foreach ($name_val as $name => $val)
+    $ret .= "<input type='hidden' name=\"$name\" value=\"$val\" />\n";
+  return $ret;
+}
+
 # Special input: textarea.
 function form_textarea ($name, $value="", $extra=false)
 {
@@ -92,7 +101,9 @@ function form_textarea ($name, $value="", $extra=false)
 }
 
 # Add submit button.
-function form_submit($text=false, $submit_name="update", $extra=false)
+function form_submit (
+  $text = false, $submit_name = "update", $extra = false, $skip_trap = false
+)
 {
   if (!$text)
     $text = _("Submit");
@@ -103,12 +114,12 @@ function form_submit($text=false, $submit_name="update", $extra=false)
   # Sure, some bots will someday implement CSS support, but the ones that does
   # not will not disappear as soon as this happen.
   $trap = '';
-  if (empty($GLOBALS['int_trapisset']) && !user_isloggedin())
+  if (!$skip_trap && empty($GLOBALS['int_trapisset']) && !user_isloggedin())
     {
-      $trap = " ".form_input("text", "website", "http://");
+      $trap = " " . form_input ("text", "website", "http://");
       $GLOBALS['int_trapisset'] = true;
     }
-  return form_input("submit", $submit_name, $text, $extra).$trap;
+  return form_input ("submit", $submit_name, $text, $extra) . $trap;
 }
 
 # Close the form, with submit button.
