@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2005-2006 Tobias Toedter <t.toedter--gmx.net>
 # Copyright (C) 2005-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2018, 2019, 2020 Ineiev
+# Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022 Ineiev
 #
 # This file is part of Savane.
 #
@@ -240,17 +240,56 @@ function markup_preserve_spaces ($buf)
   $buf = preg_replace ('/  *(\n|$)/', '$1', $buf);
   $buf = preg_replace ('/ /', '&nbsp;', $buf);
   $buf = preg_replace ('/(([&]nbsp;)*)[&]nbsp;/', '$1 ', $buf);
+  $buf = preg_replace ('/(\n) /', '$1&nbsp;', $buf);
   $buf = preg_replace ('/^((<p>)?) /', '$1&nbsp;', $buf);
   return $buf;
 }
 
+# Compile HTML text for a verbatim block, append it to $result;
+# the function is used further in markup_full ().
+function markup_build_verbatim (&$verbatim_buffer, &$context_stack, &$result)
+{
+  $line = join ("\n", $context_stack);
+  array_shift ($context_stack);
+
+  # Unify line breaks.
+  $verbatim_buffer = str_replace ("\r\n", "\n", $verbatim_buffer);
+  $verbatim_buffer = str_replace ("\n\r", "\n", $verbatim_buffer);
+  $verbatim_buffer = str_replace ("\r", "\n", $verbatim_buffer);
+  # Hopefully preserve spaces in HTML allowing line breaking.
+  $verbatim_buffer = str_replace ("\t", "        ",
+                                  $verbatim_buffer);
+  # The leading space will be collapsed in markup_preserve_spaces.
+  $verbatim_buffer = ' ' . markup_preserve_spaces ($verbatim_buffer);
+
+  # Preserve line breaks.
+  $verbatim_buffer = str_replace ("\n", "<br />\n", $verbatim_buffer);
+  # Take into account unclosed paragraphs of surrounding text.
+  $closure = $aperture = $prev_line = "";
+  if (count ($result) > 0)
+    $prev_line = $result[count($result) - 1];
+  $len = strlen ($prev_line);
+  if ($len >= 6 && substr ($prev_line, $len - 6) === '<br />')
+    {
+      $closure = "</p>\n";
+      $aperture = "<p>";
+    }
+  $result [] =
+    "$closure<blockquote class='verbatim'>"
+    . "<p>$verbatim_buffer</p></blockquote>\n$aperture";
+  $verbatim_buffer = '';
+}
+
 # Convert special markup characters in the input text to real HTML.
 #
-# This function does the same markup as markup_rich(), plus
-# it converts headings to <h2> ... <h5>.
-function markup_full($text, $allow_headings=true)
+# This function does exactly the same markup as markup_rich()
+# when !$allow_headings, plus it converts headings to <h2> ... <h5>
+# when $allow_headings.
+function markup_full($text, $allow_headings = true)
 {
-  $lines = explode("\n", $text);
+  $verb_tag = 'verbatim';
+  $no_markup_magic = 'no-1a4f67a7-4eae-4aa1-a2ef-eecd8af6a997-markup';
+  $lines = explode ("\n", $text);
   $result = array();
 
   # We use a stack (last in, first out) to track the current
@@ -259,86 +298,33 @@ function markup_full($text, $allow_headings=true)
 
   $quoted_text = false;
   $verbatim = 0;
-  extract(sane_import('request', array('printer')));
+  extract(sane_import('request', [true => 'printer']));
+  $verbatim_buffer = '';
   foreach ($lines as $index => $line)
     {
+      $found = strpos ($line, "+$verb_tag+") !== false;
+      if ($found)
+        $verbatim++;
       # The verbatim tags are not allowed to be nested, because
-      # they are translated to HTML <textarea> (<pre> in printer mode),
-      # which in turn is also not allowed to be nested.
-      # Therefore, we dont need a counter of the level, but
-      # a simple bool flag.
-      # We also need to bufferize the verbatim content, as we want to now
-      # its exact number of lines.
-      #
-      # yeupou, 2006-10-31: we need a verbatim count, because actually
-      # we may want to put at least one verbatim block into another, for
-      # instance in the recipe that explain the verbatim tag.
-      if (preg_match('/([+]verbatim[+])/', $line) and !$verbatim)
+      # they are translated to HTML code that isn't allowed to be nested.
+      if ($verbatim == 1 && $found)
         {
-          $verbatim = 1;
-          $verbatim_buffer = '';
           $line = join("\n", $context_stack);
 
-          if (empty($printer))
-            array_unshift($context_stack, '</textarea>');
+          if (empty ($printer))
+            array_unshift ($context_stack, '</textarea>');
           else
-            array_unshift($context_stack, '</pre>');
+            array_unshift ($context_stack, '</pre>');
 
-          # Jump to the next line, assuming that we can ignore the rest of the
-          # line.
+          # Jump to the next line, ignoring the rest of the line.
           continue;
         }
 
-      # Increment the verbatim count if we find a verbatim closing in a
-      # verbatim environment.
-      if (preg_match('/([+]verbatim[+])/', $line) and $verbatim)
-        $verbatim++;
-
-      # Decrement the verbatim count if we find a verbatim closing in a
-      # verbatim environment.
-      if (preg_match ('/([-]verbatim[-])/', $line) && $verbatim)
+      if (strpos ($line, "-$verb_tag-") !== false && --$verbatim <= 0)
         {
-          $verbatim--;
-          if ($verbatim == 0)
-            {
-              # End of verbatim: process the block.
-              $line = join("\n", $context_stack);
-              array_shift($context_stack);
-
-              # Unify line breaks.
-              $verbatim_buffer = str_replace ("\r\n", "\n", $verbatim_buffer);
-              $verbatim_buffer = str_replace ("\n\r", "\n", $verbatim_buffer);
-              $verbatim_buffer = str_replace ("\r", "\n", $verbatim_buffer);
-              # Hopefully preserve spaces in HTML allowing line breaking.
-              $verbatim_buffer = str_replace ("\t", "        ",
-                                              $verbatim_buffer);
-              # The first space will be collapsed.
-              $verbatim_buffer = ' ' . markup_preserve_spaces ($verbatim_buffer);
-
-              # Preserve line breaks.
-              $verbatim_buffer = str_replace ("\n", "<br />\n",
-                                              $verbatim_buffer);
-              # Take into account unclosed paragraphs of surrounding text.
-              $closure = "";
-              $aperture = "";
-              $prev_line = "";
-              if (count($result) > 0)
-                $prev_line = $result[count($result) - 1];
-              $len = strlen ($prev_line);
-              if ($len >= 6 && substr ($prev_line, $len - 6) === '<br />')
-                {
-                  $closure = "</p>\n";
-                  $aperture = "<p>";
-                }
-              $result[] = $closure . '<blockquote class="verbatim"><p>'
-                          . $verbatim_buffer . "</p></blockquote>\n" . $aperture;
-              $verbatim_buffer = '';
-
-              # Jump to the next line, assuming that we can ignore the rest of the
-              # line.
-              continue;
-            } # $verbatim == 0
-        } # preg_match ('/([-]verbatim[-])/', $line) && $verbatim
+          markup_build_verbatim ($verbatim_buffer, $context_stack, $result);
+          continue;
+        }
 
       # If we're in the verbatim markup, don't apply the markup.
       if ($verbatim)
@@ -347,19 +333,19 @@ function markup_full($text, $allow_headings=true)
           # This has to be done in the original string, because that
           # is the one which will be split upon the +nomarkup+ tags,
           # see below.
-          $escaped_line = str_replace('nomarkup',
-            'no-1a4f67a7-4eae-4aa1-a2ef-eecd8af6a997-markup', $line);
+          $escaped_line = str_replace ('nomarkup', $no_markup_magic, $line);
           $lines[$index] = $escaped_line;
-          $verbatim_buffer .= $escaped_line . "\n";
+          $verbatim_buffer .= "$escaped_line\n";
+          continue;
         }
-      else
-        {
-          # Otherwise, normal run, do the markup.
-          $line = _full_markup($line, $allow_headings, $context_stack,
-                               $quoted_text);
-          $result[] = markup_preserve_spaces ($line);
-        }
-    }
+      # Normal run, do the markup.
+      $line =
+        _full_markup ($line, $allow_headings, $context_stack, $quoted_text);
+      $result[] = markup_preserve_spaces ($line);
+    } # foreach ($lines as $index => $line)
+
+  if ($verbatim) # Missing "-$verb_tag-": append accumulated text.
+    markup_build_verbatim ($verbatim_buffer, $context_stack, $result);
 
   # Make sure that all previously used contexts get their
   # proper closing tag by merging in the last closing tags.
@@ -422,8 +408,7 @@ function markup_full($text, $allow_headings=true)
 
   # Lastly, revert the escaping of +nomarkup+ tags done above
   # for verbatim environments.
-  return str_replace('no-1a4f67a7-4eae-4aa1-a2ef-eecd8af6a997-markup',
-    'nomarkup', join('', $markup));
+  return str_replace ($no_markup_magic, 'nomarkup', join ('', $markup));
 }
 
 # Convert whatever content that can contain markup to a valid text output
@@ -747,6 +732,16 @@ function _markup_inline($line)
   # we can expect web browsers to support).
   $protocols = "https?|ftp|sftp|file|afs|nfs";
 
+  # Artificial protocol for protocol-relative links.
+  $protocol_relative = "p-r";
+  # Make sure $line doesn't contain $protocol_relative.
+  $pr_esc = "p-&#83521;-r";
+  $line = str_replace ($protocol_relative, $pr_esc, $line);
+
+  # Reword "//" as artificial "protocol".
+  $line = preg_replace('#(^|\s|\[)//#', '$1' . $protocol_relative . '://', $line);
+  $protocols .= '|' . $protocol_relative;
+
   # Links between items.
   # FIXME: It should be i18n, but in a clever way, meaning that everytime
   # a form is submitted with such string, the string get converted in
@@ -768,7 +763,7 @@ function _markup_inline($line)
   # Modify link texts to disable interpreting them as nested links.
   $line = preg_replace_callback ('/(\[(('
         .$protocols.'|www\.)[^\s]+'
-        .'|(('.$artifact_regex.')\s{0,2}#[0-9]+))\s+)(.*?)\]/',
+        . '|((' . $artifact_regex . ')\s{0,2}#[0-9]+))\s+)(.*?)\]/',
         function ($matches)
           {
         # Replace '#' in link texts with HTML references;
@@ -783,16 +778,11 @@ function _markup_inline($line)
             return $matches[1].$tail.']';
           }, $line);
 
-  # Prepare usual links: prefix "www." with "http://"
-  # if it is preceded by [ or whitespace or at the beginning of line.
-  # (don't want to prefix in cases like "//www.." or "ngwww...")
-  $line = preg_replace('/(^|\s|\[)(www\.)/i', '$1http://$2', $line);
-
-  # Replace the @ sign with an HTML entity, if it is used within
-  # an url (e.g. for pointers to mailing lists). This way, the
-  # @ sign doesn't get mangled in the e-mail markup code
-  # below. See bug #2689 on http://gna.org/ for reference.
-  $line = preg_replace ("#([a-z]+://[^<>[:space:]]+)@#i", "\\1&#64;", $line);
+  # Prepare usual links: prefix "www." with $protocol_relative . "://"
+  # if it is preceded by [ or whitespace or at the beginning of line
+  # (don't want to prefix in cases like "//www.." or "ngwww...").
+  $line = preg_replace('/(^|\s|\[)(www\.)/i',
+                       '$1' . $protocol_relative . '://$2', $line);
 
   # Prepare the markup for normal links, e.g. http://test.org, by
   # surrounding them with braces []
@@ -804,10 +794,17 @@ function _markup_inline($line)
   # Remove spaces added with preg_replace_callback
   # and process links with preceding ';'.
   $line = preg_replace ('/&#32;/', '', $line);
-  $line = preg_replace('/(;)(('.$protocols
-                       .'):\/\/(&amp;|[^\s&]+[a-z0-9\/^])+)/i',
+  $line = preg_replace('/(;)(((' . $protocols
+                       . '):)?\/\/(&amp;|[^\s&]+[a-z0-9\/^])+)/i',
     '$1[$2]', $line);
 
+  # Replace the @ sign with an HTML entity, if it is used within
+  # an URL (e.g. for pointers to mailing lists).  This way, the
+  # @ sign doesn't get mangled in the e-mail markup code
+  # below.
+  $line = preg_replace ("#((" . $protocols . ")://[^<>[:space:]]+)@#i",
+                        "$1&#64;", $line);
+
   # Do a markup for mail links, e.g. info@support.org
   # (do not use utils_emails, this does extensive database
   # search on the string
@@ -817,6 +814,10 @@ function _markup_inline($line)
   $line = preg_replace("/(^|\s)([a-z0-9_+-.]+@([a-z0-9_+-]+\.)+[a-z]+)(\s|$)/i",
                        '\1' . utils_email_basic('\2') . '\4', $line);
 
+  # Unreplace the @ sign.
+  $line = preg_replace ("%((" . $protocols . ")://[^<>[:space:]]+)[&]#64;%i",
+                        "$1@", $line);
+
   foreach ($trackers as $regexp => $link)
     {
       # Allow only two white spaces between the string and the numeric id
@@ -844,8 +845,8 @@ function _markup_inline($line)
   $line = preg_replace(
     # Find the opening brace '['
     '/\['
-    # followed by the protocol, either http:// or https://
-    .'(('.$protocols.'):\/\/'
+    # followed by the protocol
+    . '(((' . $protocols . '):)?\/\/'
     # match any character except whitespace or the closing
     # brace ']' for the actual link
     .'[^\s\]]+)'
@@ -853,7 +854,7 @@ function _markup_inline($line)
     .'\s+'
     # followed by any character (non-greedy) and the
     # next closing brace ']'.
-    .'(.+?)\]/', '<a href="$1">$3</a>', $line);
+    .'(.+?)\]/', '<a href="$1">$4</a>', $line);
 
   # Add support for unnamed hyperlinks, e.g.
   # [http://gna.org/] -> <a href="http://gna.org/">http://gna.org/</a>
@@ -862,17 +863,22 @@ function _markup_inline($line)
   $line = preg_replace_callback(
     # Find the opening brace '['
     '/\['
-    # followed by the protocol, either http:// or https://
-    # (FIXME: which protocol does it makes sense to support, which one
-    # should we ignore?)
-    .'(('.$protocols.'):\/\/'
+    # followed by the protocol
+    . '(((' . $protocols . '):)?\/\/'
     # match any character except whitespace (non-greedy) for
     # the actual link, followed by the closing brace ']'.
-    .'[^\s]+?)\]/', function ($match)
+    . '([^\s]+?))\]/', function ($match) use ($protocol_relative)
                       {
-                        return utils_cutlink($match[1]);
+                        $url = $match[1];
+                        $string = $url;
+                        if ($match[3] == $protocol_relative)
+                          $string = $match[4];
+                        return '<a href="' . $url . '">' . $string . '</a>';
                       }, $line);
 
+  $line = str_replace ($protocol_relative . "://", "//", $line);
+  $line = str_replace ($pr_esc, $protocol_relative, $line);
+
   # *word* -> <strong>word</strong>
   $line = preg_replace(
     # Find an asterisk after a space or starting the line
@@ -909,4 +915,41 @@ function _markup_inline($line)
     }
   return $line;
 }
+
+# Process a single line for markup_ascii ().
+function markup_ascii_line ($line, &$item_no)
+{
+  # Purge all list indices starting from $n.
+  $markup_trim_item_no = function (&$item_no, $n)
+  {
+    $cnt = count ($item_no);
+    for ($i = $n; $i < $cnt; $i++)
+      unset ($item_no[$i]);
+  };
+  $indent_base = "\t";
+  if (!preg_match('/^\s?([0]+) (.+)$/', $line, $matches))
+    {
+      $item_no = [];
+      return $line;
+    }
+  $n = strlen ($matches[1]);
+  $markup_trim_item_no ($item_no, $n);
+  $n--;
+  if (empty ($item_no[$n]))
+    $item_no[$n] = 0;
+  $item_no[$n]++;
+  return str_repeat ($indent_base, $n) . "{$item_no[$n]}. {$matches[2]}";
+}
+
+# Implement applicable parts of tracker comment in ASCII, which currently
+# amounts to enumerations in ordered lists, Savannah sr #110621.
+function markup_ascii ($text)
+{
+  $lines = explode ("\n", utils_unconvert_htmlspecialchars ($text));
+  $item_no = [];
+  $ret = '';
+  foreach ($lines as $line)
+    $ret .= markup_ascii_line ($line, $item_no) . "\n";
+  return $ret;
+}
 ?>
