@@ -62,22 +62,11 @@ function trackers_votes_user_giventoitem_count ($user_id, $tracker, $item_id)
 # Update the database: add / update votes
 function trackers_votes_update ($item_id, $group_id=0, $new_vote, $tracker=null)
 {
-  # Vote must be simple integer
-  if (!ctype_digit($new_vote))
-    {
-      fb(_("Vote provided is not a simple integer, it has been ignored"), 1);
-      return false;
-    }
-
   # If the tracker is undefined, use the constant,
   if (!$tracker)
-    {
-      $tracker = ARTIFACT;
-    }
+    $tracker = ARTIFACT;
 
-  assert('ctype_alnum($tracker)');
-
-  # If group_id is not known, we guess it
+  # If group_id is not known, we guess it.
   if (!$group_id)
     {
       $res_getgroupid = db_execute("SELECT group_id FROM ".$tracker
