@@ -4,7 +4,7 @@
 # Copyright (C) 1999-2000 The SourceForge Crew
 # Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2017, 2018 Ineiev
+# Copyright (C) 2017, 2018, 2022 Ineiev
 #
 # This file is part of Savane.
 #
@@ -26,8 +26,21 @@ require_once('../../include/account.php');
 require_once('../../include/sendmail.php');
 session_require(array('isloggedin' => 1));
 
-extract(sane_import('post', array('update', 'keys', 'form_authorized_keys',
-                                  'form_id')));
+extract (sane_import ('post',
+  [
+    'true' => 'update',
+    'hash' => 'form_id',
+    'array' =>
+      [
+        ['form_authorized_keys', ['digits', 'no_quotes']]
+      ]
+  ]
+));
+
+$key_limit = 25; # Maximum key number to register.
+$min_keys = 5; # Minumum key fields to show.
+$key_separator = "###";
+
 if ($update)
   {
     if (!form_check($form_id))
@@ -35,8 +48,7 @@ if ($update)
 
     $keys = '';
     # Build the key string.
-    # Key limit is set to 25.
-    for ($i = 0; $i < 25; $i++)
+    for ($i = 0; $i < $key_limit; $i++)
       {
         if (!isset($form_authorized_keys[$i]))
           continue;
@@ -67,14 +79,14 @@ if ($update)
             if ($return_value != 0)
               {
                 fb(sprintf(_("Key #%s seen"), $i+1));
-                $keys .= $thiskey."###";
+                $keys .= $thiskey . $key_separator;
               }
             else
               fb(sprintf(
 # TRANSLATORS: the argument is a link to a page.
 _('Error: ssh-vulnkey detected key #%s as compromised.
 Please upgrade your system and regenerate it
-(see %s for more information).'), $i+1, 'http://wiki.debian.org/SSLkeys'),
+(see %s for more information).'), $i + 1, '//wiki.debian.org/SSLkeys'),
                  1);
           }
       }
@@ -84,9 +96,11 @@ Please upgrade your system and regenerate it
                                 array(user_getid()));
     $row_orig_keys = db_fetch_array($res_orig_keys);
     $orig_keys = $row_orig_keys['authorized_keys'];
-    $new_keys = array_diff(explode ("###", $keys), explode ('###', $orig_keys));
+    $new_keys = array_diff (
+      explode ($key_separator, $keys), explode ($key_separator, $orig_keys)
+    );
 
-    if (count($new_keys))
+    if (count ($new_keys))
       {
         $user_id = user_getid();
         $message = sprintf(
@@ -95,12 +109,14 @@ _('Someone, presumably you, has changed your SSH keys on %s.
 If it wasn\'t you, maybe someone is trying to compromise your account...'),
                            $GLOBALS['sys_name'])."\n\n";
 
-        $message .= sprintf(
-_('The request came from %s
-(IP: %s, port: %s, user agent: %s)'),
-  gethostbyaddr($_SERVER['REMOTE_ADDR']),
-$_SERVER['REMOTE_ADDR'], $_SERVER['REMOTE_PORT'], $_SERVER['HTTP_USER_AGENT']
-)."\n\n";
+        $message .=
+          sprintf(
+            _('The request came from %s
+(IP: %s, port: %s, user agent: %s)') . "\n\n",
+            gethostbyaddr ($_SERVER['REMOTE_ADDR']),
+            $_SERVER['REMOTE_ADDR'], $_SERVER['REMOTE_PORT'],
+            $_SERVER['HTTP_USER_AGENT']
+          );
 
 # TRANSLATORS: the argument is site name (like Savannah).
         $message .= sprintf(_("-- the %s team."),$GLOBALS['sys_name'])."\n";
@@ -111,14 +127,18 @@ $_SERVER['REMOTE_ADDR'], $_SERVER['REMOTE_PORT'], $_SERVER['HTTP_USER_AGENT']
                       ._("SSH key changed on your account"),
                       $message);
       }
-    # Update the database.
-    $success = 0;
-    if ($keys != '')
-      $success = db_execute("UPDATE user SET authorized_keys = ? "
-                            ."WHERE user_id = ?",
-                            array($keys, user_getid()));
+    $success =
+      db_execute (
+        "UPDATE user SET authorized_keys = ? WHERE user_id = ?",
+        [$keys, user_getid()]
+      );
     if ($success)
-      fb(_("Keys registered"));
+      {
+        if ($keys == '')
+          fb(_("No key is registered"));
+        else
+          fb(_("Keys registered"));
+      }
     else
       fb(_("Error while registering keys"), 1);
   }
@@ -128,34 +148,39 @@ else # !$update
     $res_keys = db_execute("SELECT authorized_keys FROM user WHERE user_id = ?",
                            array(user_getid()));
     $row_keys = db_fetch_array($res_keys);
-    $form_authorized_keys = explode ("###", $row_keys['authorized_keys'], 25);
+    $keys = $row_keys['authorized_keys'];
   }
+
+$form_authorized_keys =  explode ($key_separator, $keys);
+
 # Not valid registration, or first time to page.
 site_user_header(array('title' => _("Change Authorized Keys"),
                        'context' => 'account'));
 print form_header($_SERVER['PHP_SELF'], false, "post");
-print '<h2>'._("Authorized keys")."</h2>\n";
+print '<h2>' . _("Authorized keys") . "</h2>\n";
 utils_get_content("account/editsshkeys");
 print '<p>'
-._("Fill the text fields below with the public keys for each key you want to
+ . _("Fill the text fields below with the public keys for each key you want to
 register. After submitting, verify that the number of keys registered is what
-you expected.").'</p>
-';
+you expected.") . "</p>\n";
 
-# Key limit is set to 25.
-# By default, show only 5 fields.
-$i = 0;
-while($i < count($form_authorized_keys) or $i < 5)
+$n = count ($form_authorized_keys);
+if ($n < $min_keys)
+  $n = $min_keys;
+if ($n > $key_limit)
+  $n = $key_limit;
+
+for ($i = 0; $i < $n; $i++)
   {
-    $thiskey = array_key_exists($i, $form_authorized_keys)
-      ? $form_authorized_keys[$i] : '';
-    print '<span class="preinput"><label for="form_authorized_keys['.$i.']">'
-      . sprintf(_("Key #%s:"), $i+1)
-      . "</label></span>\n<input type='text' size='60' "
-      . "id='form_authorized_keys[$i]' name='form_authorized_keys[$i]'\n      "
-      . "value='$thiskey' /><br />\n";
-    $i++;
+    $thiskey = '';
+    if (isset ($form_authorized_keys[$i]))
+      $thiskey = $form_authorized_keys[$i];
+    print "<span class=\"preinput\"><label for=\"form_authorized_keys[$i]\">";
+    printf (_("Key #%s:"), $i + 1);
+    print "</label></span>\n<input type='text' size='60' "
+      . "id='form_authorized_keys[$i]' name='form_authorized_keys[$i]'\n"
+      . "      value='$thiskey' /><br />\n";
   }
-print "<br />\n".form_footer(_("Update"));
+print "<br />\n" . form_footer (_("Update"));
 site_user_footer(array());
 ?>
